@@ -14,7 +14,7 @@
 ## See <http://www.gnu.org/licenses/>
 
 #' This function removes spaces and punctuations from filenames.
-#' 
+#'
 #' @return filename
 #'
 #' @keywords internal
@@ -26,7 +26,7 @@
 #' Determine file extension
 #'
 #' @param x \code{character}, filename.
-#' 
+#'
 #' @return \code{character}, file extension.
 #'
 #' @seealso \code{\link[MALDIquant]{MassSpectrum-class}}
@@ -38,13 +38,20 @@
 #' MALDIquantForeign:::.fileExtension(files)
 #'
 .fileExtension <- function(x) {
-  pos <- regexpr(pattern="\\.([[:alnum:]]+)$|(/|\\\\)+[^.\\\\/]+$", text=x)
+  pos <- regexpr(pattern="(\\.tar)?\\.([[:alnum:]]+)$|(/|\\\\)+[^.\\\\/]+$",
+                 text=x)
   return(ifelse(pos > -1L, substring(x, pos+1L), x))
 }
 
 #' @keywords internal
 .withoutFileExtension <- function(x) {
-  return(sub(pattern="\\.[[:alnum:]]+\\.?(gz|bz2|xz)?$|(/|\\\\)+[^.\\\\/]+$",
+  return(sub(pattern="\\.[[:alnum:]]+?$|(/|\\\\)+[^.\\\\/]+$",
+             replacement="", x=.withoutCompressionExtension(x)))
+}
+
+#' @keywords internal
+.withoutCompressionExtension <- function(x) {
+  return(sub(pattern="\\.(zip|gz|bz2|bzip2|xz|lzma)+$",
              replacement="", x=x))
 }
 
@@ -59,7 +66,7 @@
 
   for (i in seq(along=l)) {
     cols <- 1:nCol[i]
-    m[i, cols] <- l[[i]] 
+    m[i, cols] <- l[[i]]
   }
 
   isIdentical <- apply(m, 2, function(co)all(co[1] == co))
@@ -83,11 +90,24 @@
                                  sep="_") {
   filenames <- .cutFilenames(.withoutFileExtension(x))
   filenames <- .cleanFilename(filenames)
-  
+
   empty <- nchar(filenames) <= 0
   filenames[empty] <- seq_along(empty)
 
-  filenames <- make.unique(filenames, sep=sep)
+  filenames <- .make.unique(filenames, sep=sep)
   return(paste(filenames, fileExtension, sep="."))
 }
 
+#' @keywords internal
+## let make unique start by 1
+.make.unique <- function(x, sep="_") {
+  tmp <- lapply(split(x, x), function(y) {
+    n <- length(y)
+    if (n > 1) {
+      fmt <- paste("%s%s%0", floor(log10(n))+1, "d", sep="")
+      y <- sprintf(fmt=fmt, y, sep, 1:n)
+    }
+    return(y)
+  })
+  return(unsplit(tmp, x))
+}
